@@ -71,3 +71,14 @@ class MongoDBInterface(DBInterface, dict):
         result = cli.delete_one(select_filter)
         self.removed_connect()
         return result
+
+    def dump(self):
+        cli = self.get_connect()
+        result = cli.find({})
+        if result is None:
+            return result
+        result = dict(result)
+        del result["_id"]
+
+        self.removed_connect()
+        return result
